@@ -356,9 +356,6 @@ func (x *Ident) Pos() token.Pos { return x.NamePos }
 // Pos returns position of first character belonging to the node.
 func (x *Ellipsis) Pos() token.Pos { return x.Ellipsis }
 
-// Pos returns position of first character belonging to the node.
-func (x *BasicLit) Pos() token.Pos { return x.ValuePos }
-
 // Pos returns position of first character belonging to the node.
 func (x *FuncLit) Pos() token.Pos { return x.Type.Pos() }
 
@@ -440,9 +437,6 @@ func (x *Ellipsis) End() token.Pos {
 	return x.Ellipsis + 3 // len("...")
 }
 
-// End returns position of first character immediately after the node.
-func (x *BasicLit) End() token.Pos { return token.Pos(int(x.ValuePos) + len(x.Value)) }
-
 // End returns position of first character immediately after the node.
 func (x *FuncLit) End() token.Pos { return x.Body.End() }
 
@@ -520,7 +514,6 @@ func (x *ChanType) End() token.Pos { return x.Value.End() }
 func (*BadExpr) exprNode()        {}
 func (*Ident) exprNode()          {}
 func (*Ellipsis) exprNode()       {}
-func (*BasicLit) exprNode()       {}
 func (*FuncLit) exprNode()        {}
 func (*CompositeLit) exprNode()   {}
 func (*ParenExpr) exprNode()      {}
@@ -604,13 +597,6 @@ type (
 		X Expr // expression
 	}
 
-	// A SendStmt node represents a send statement.
-	SendStmt struct {
-		Chan  Expr
-		Arrow token.Pos // position of "<-"
-		Value Expr
-	}
-
 	// An IncDecStmt node represents an increment or decrement statement.
 	IncDecStmt struct {
 		X      Expr
@@ -815,9 +801,6 @@ func (s *LabeledStmt) End() token.Pos { return s.Stmt.End() }
 // End returns position of first character immediately after the node.
 func (s *ExprStmt) End() token.Pos { return s.X.End() }
 
-// End returns position of first character immediately after the node.
-func (s *SendStmt) End() token.Pos { return s.Value.End() }
-
 // End returns position of first character immediately after the node.
 func (s *IncDecStmt) End() token.Pos {
 	return s.TokPos + 2 /* len("++") */
